@@ -6,9 +6,6 @@ use 5.012;
 use autodie;
 use Text::Cadenceparser;
 
-# ABSTRACT: Create a short human-readable output of the synthesis logfiles
-# PODNAME: synth_log.pl
-
 if ( defined $ARGV[0] ) {
 
     # Create the object
@@ -31,6 +28,9 @@ if ( defined $ARGV[0] ) {
 "Please pass the folder with the files that need to be parsed as command line option";
 }
 
+# ABSTRACT: Create a short human-readable output of the synthesis logfiles
+# PODNAME: synth_log.pl
+
 __END__
 
 =pod
@@ -41,7 +41,18 @@ synth_log.pl - Create a short human-readable output of the synthesis logfiles
 
 =head1 VERSION
 
-version 1.08
+version 1.09
+
+=head1 DESCRIPTION
+
+This scripts produces a list of warnings and errors that were encountered in the parsed folder.
+
+=head1 SYNOPSYS
+
+Usage:
+synth_log.pl <folder>
+
+Where <folder> needs to be the REPORTS folder of the synthesis run.
 
 =head1 AUTHOR
 
